# Generated by Django 5.1 on 2024-08-09 13:44

import django.db.models.deletion
import django_polly.lib.llm_api
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Parrot',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('external_id', models.CharField(blank=True, max_length=255, null=True, unique=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('name', models.CharField(max_length=100)),
                ('color', models.CharField(max_length=50)),
                ('age', models.IntegerField(default=0)),
                ('model', models.CharField(choices=[('mistral-7b-instruct-v0.1.Q4_0.gguf', 'MISTRAL_0_1_INSTRUCT'), ('Meta-Llama-3-8B-Instruct.Q8_0.gguf', 'META_LLAMA_3_INSTRUCT'), ('Meta-Llama-3.1-8B-Instruct.Q4_0.gguf', 'META_LLAMA_3_1_INSTRUCT'), ('Phi-3-mini-4k-instruct.Q4_0.gguf', 'PHI_3_MINI_INSTRUCT'), ('Qwen2-500M-Instruct-Q8_0.gguf', 'QWEN2_INSTRUCT'), ('llama-pro-8b.Q8_0.gguf', 'LLAMA_PRO')], default=django_polly.lib.llm_api.LLMModelType['QWEN2_INSTRUCT'], max_length=255)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SmartConversation',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('external_id', models.CharField(blank=True, max_length=255, null=True, unique=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Message',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('external_id', models.CharField(blank=True, max_length=255, null=True, unique=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('content', models.TextField()),
                ('party', models.CharField(choices=[('USER', 'User'), ('ASSISTANT', 'Assistant')], max_length=10)),
                ('conversation', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_polly.smartconversation')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Trick',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('external_id', models.CharField(blank=True, max_length=255, null=True, unique=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('name', models.CharField(max_length=100)),
                ('difficulty', models.CharField(choices=[('easy', 'Easy'), ('medium', 'Medium'), ('hard', 'Hard')], max_length=20)),
                ('description', models.TextField(blank=True)),
                ('parrot', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='tricks', to='django_polly.parrot')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
