# Generated by Django 5.0 on 2024-08-11 20:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_polly', '0002_smartconversation_title_alter_message_conversation_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='smartconversation',
            name='title',
            field=models.CharField(blank=True, default='Untitled Smart Conversation', max_length=255),
        ),
    ]
