<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Smart Conversation - Access Denied</title>
    <script src="https://cdn.tailwindcss.com"></script>
</head>
<body class="bg-gray-100">
<div class="flex justify-center">
    <div class="bg-white p-4 shadow-lg rounded-lg m-4">
        <h2 class="text-xl font-bold text-red-600">Access Denied</h2>
    </div>
</div>
</body>
</html>